intelmq.bots.outputs.blackhole package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.blackhole package

## Submodules

## intelmq.bots.outputs.blackhole.output module

intelmq.bots.outputs.blackhole.output.BOT

  alias of `intelmq.bots.outputs.blackhole.output.BlackholeOutputBot`

class intelmq.bots.outputs.blackhole.output.BlackholeOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Discard messages

  process()

## Module contents